@@ -19,3 +19,11 @@ check4pkg <- function(x) {
     invisible(TRUE)
   }
 }
+
+check_inputs <- function(x) {
+  calls <- names(sapply(x, deparse))[-1]
+  calls_vec <- "point_color" %in% calls
+  if (any(calls_vec)) {
+    stop("The parameter 'point_color' has been replaced by 'color'", call. = FALSE)
+  }
+}
